==> print-manager-4.14.3.tar.xz: print-manager-4.14.3/configure-printer/ConfigurePrinter.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef CONFIGURE_PRINTER_H
#define CONFIGURE_PRINTER_H

#include <KUniqueApplication>

class ConfigurePrinterInterface;
class ConfigurePrinter : public KUniqueApplication
{
    Q_OBJECT
public:
    ConfigurePrinter();
    virtual ~ConfigurePrinter();

    int newInstance();

private:
    ConfigurePrinterInterface *m_cpInterface;
};

#endif // CONFIGURE_PRINTER_H

==> print-manager-16.04.2.tar.xz: print-manager-16.04.2/configure-printer/ConfigurePrinter.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef CONFIGURE_PRINTER_H
#define CONFIGURE_PRINTER_H

#include <QApplication>

class ConfigurePrinterInterface;
class ConfigurePrinter : public QApplication
{
    Q_OBJECT
public:
    ConfigurePrinter(int & argc, char ** argv);
    virtual ~ConfigurePrinter();

    void configurePrinter(const QString &printer);
private:
    ConfigurePrinterInterface *m_cpInterface;
};

#endif // CONFIGURE_PRINTER_H
